@@ -18,34 +18,34 @@
 */
 
 /** @file swephelp.h
-** @brief swephelp export header file.
+** @brief swephelp export header file
 **
 ** Main swephelp header, imports all swephelp functions and defines.
-**
-** @author Stanislas Marquis <stnsls@gmail.com>
-** @date 11.01.2009
-** @remarks Based on swisseph version 1.75.00
 */
 
 #ifndef SWEPHELP_H
 #define SWEPHELP_H
 
+/* pollute namespace with fancy aliases */
 #ifndef SWH_USE_ALIASES
 #define SWH_USE_ALIASES     1
 #endif
 
+/* on platform where possible */
 #ifndef SWH_USE_THREADS
 #define SWH_USE_THREADS     1
 #endif
 
+/* include swisseph functions */
 #include <swephexp.h>
 
-#include "swhdef.h"
+/* swephelp headers */
 #include "swhdatetime.h"
+#include "swhdef.h"
 #include "swhformat.h"
-#include "swhsearch.h"
-#include "swhraman.h"
 #include "swhgeo.h"
+#include "swhraman.h"
+#include "swhsearch.h"
 #include "swhutil.h"
 
-#endif /* swephelp.h */
+#endif /* SWEPHELP_H */
