@@ -34,7 +34,7 @@ extern "C"
 */
 static double swh_precision = ((1.0/86400)/2);
 
-/** @def ISPOSITIVE(x)
+/** @def ISPOSITIVE
 ** @brief Return 1 if x is greater than 0, else return 0
 */
 #define ISPOSITIVE(x)   ((x) > 0 ? 1 : 0)
@@ -843,36 +843,31 @@ int swh_match_aspect2(double pos0, double speed0, double pos1, double speed1,
 /** @brief Aspect matching
 **
 ** Same as swh_match_aspect, but with a different orb in case aspect is
-** applying or separating.
-**
-** @remarks This kind of search probably doesnt make much sense when objects
-** speeds are equal (because the aspect will never be applying or separating).
-** In that case, the function will fallback on swh_match_aspect using the
-** smallest orb given.
+** applying, separating, or stable.
 **
 ** @see swh_match_aspect()
 */
 int swh_match_aspect3(double pos0, double speed0, double pos1, double speed1,
-    double aspect, double a_orb, double s_orb, double *diffret, int *applic,
-    double *factor)
+    double aspect, double app_orb, double sep_orb, double def_orb,
+    double *diffret, int *applic, double *factor)
 {
-    a_orb = fabs(a_orb);
-    s_orb = fabs(s_orb);
-    if (a_orb == s_orb)
-    {
-        return swh_match_aspect(pos0, speed0, pos1, speed1, aspect, a_orb,
-            diffret, applic, factor);
-    }
+    app_orb = fabs(app_orb);
+    sep_orb = fabs(sep_orb);
+    def_orb = fabs(def_orb);
     if (speed0 == speed1)
-    {
+    { /* stable aspect */
         return swh_match_aspect(pos0, speed0, pos1, speed1, aspect,
-            a_orb < s_orb ? a_orb : s_orb,
+            def_orb, diffret, applic, factor);
+    }
+    if (app_orb == sep_orb)
+    {
+        return swh_match_aspect(pos0, speed0, pos1, speed1, aspect, app_orb,
             diffret, applic, factor);
     }
     int i;
-    if (a_orb > s_orb)
+    if (app_orb > sep_orb)
     {
-        i = swh_match_aspect(pos0, speed0, pos1, speed1, aspect, a_orb,
+        i = swh_match_aspect(pos0, speed0, pos1, speed1, aspect, app_orb,
             diffret, applic, factor);
         if (i == 0)
         {
@@ -880,9 +875,9 @@ int swh_match_aspect3(double pos0, double speed0, double pos1, double speed1,
             {
                 return 0;
             }
-            else if (*diffret <= s_orb)
+            else if (*diffret <= sep_orb)
             {
-                *factor = *diffret / s_orb;
+                *factor = *diffret / sep_orb;
                 return 0;
             }
             else
@@ -897,7 +892,7 @@ int swh_match_aspect3(double pos0, double speed0, double pos1, double speed1,
     }
     else
     {
-        i = swh_match_aspect(pos0, speed0, pos1, speed1, aspect, s_orb,
+        i = swh_match_aspect(pos0, speed0, pos1, speed1, aspect, sep_orb,
             diffret, applic, factor);
         if (i == 0)
         {
@@ -905,9 +900,9 @@ int swh_match_aspect3(double pos0, double speed0, double pos1, double speed1,
             {
                 return 0;
             }
-            else if (*diffret <= a_orb)
+            else if (*diffret <= app_orb)
             {
-                *factor = *diffret / a_orb;
+                *factor = *diffret / app_orb;
                 return 0;
             }
             else
@@ -925,36 +920,31 @@ int swh_match_aspect3(double pos0, double speed0, double pos1, double speed1,
 /** @brief Aspect matching
 **
 ** Same as swh_match_aspect2, but with a different orb in case aspect is
-** applying or separating.
-**
-** @remarks This kind of search probably doesnt make much sense when objects
-** speeds are equal (because the aspect will never be applying or separating).
-** In that case, the function will fallback on swh_match_aspect2 using the
-** smallest orb given.
+** applying, separating, or stable.
 **
 ** @see swh_match_aspect2()
 */
 int swh_match_aspect4(double pos0, double speed0, double pos1, double speed1,
-    double aspect, double a_orb, double s_orb, double *diffret, int *applic,
-    double *factor)
+    double aspect, double app_orb, double sep_orb, double def_orb,
+    double *diffret, int *applic, double *factor)
 {
-    a_orb = fabs(a_orb);
-    s_orb = fabs(s_orb);
-    if (a_orb == s_orb)
-    {
-        return swh_match_aspect2(pos0, speed0, pos1, speed1, aspect, a_orb,
-            diffret, applic, factor);
-    }
+    app_orb = fabs(app_orb);
+    sep_orb = fabs(sep_orb);
+    def_orb = fabs(def_orb);
     if (speed0 == speed1)
-    {
+    { /* stable aspect */
         return swh_match_aspect2(pos0, speed0, pos1, speed1, aspect,
-            a_orb < s_orb ? a_orb : s_orb,
+            def_orb, diffret, applic, factor);
+    }
+    if (app_orb == sep_orb)
+    {
+        return swh_match_aspect2(pos0, speed0, pos1, speed1, aspect, app_orb,
             diffret, applic, factor);
     }
     int i;
-    if (a_orb > s_orb)
+    if (app_orb > sep_orb)
     {
-        i = swh_match_aspect2(pos0, speed0, pos1, speed1, aspect, a_orb,
+        i = swh_match_aspect2(pos0, speed0, pos1, speed1, aspect, app_orb,
             diffret, applic, factor);
         if (i == 0)
         {
@@ -962,9 +952,9 @@ int swh_match_aspect4(double pos0, double speed0, double pos1, double speed1,
             {
                 return 0;
             }
-            else if (*diffret <= s_orb)
+            else if (*diffret <= sep_orb)
             {
-                *factor = *diffret / s_orb;
+                *factor = *diffret / sep_orb;
                 return 0;
             }
             else
@@ -979,7 +969,7 @@ int swh_match_aspect4(double pos0, double speed0, double pos1, double speed1,
     }
     else
     {
-        i = swh_match_aspect2(pos0, speed0, pos1, speed1, aspect, s_orb,
+        i = swh_match_aspect2(pos0, speed0, pos1, speed1, aspect, sep_orb,
             diffret, applic, factor);
         if (i == 0)
         {
@@ -987,9 +977,9 @@ int swh_match_aspect4(double pos0, double speed0, double pos1, double speed1,
             {
                 return 0;
             }
-            else if (*diffret <= a_orb)
+            else if (*diffret <= app_orb)
             {
-                *factor = *diffret / a_orb;
+                *factor = *diffret / app_orb;
                 return 0;
             }
             else
